summaryrefslogtreecommitdiff
path: root/mp.c
diff options
context:
space:
mode:
Diffstat (limited to 'mp.c')
-rw-r--r--mp.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/mp.c b/mp.c
index 19e18d1..c6e7d3f 100644
--- a/mp.c
+++ b/mp.c
@@ -191,6 +191,8 @@ mp_bcpu(void)
return bcpu-cpus;
}
+extern void mpmain(void);
+
void
mp_startthem()
{
@@ -205,7 +207,7 @@ mp_startthem()
if (c == cpu()) continue;
cprintf ("starting processor %d\n", c);
*(unsigned *)(APBOOTCODE-4) = (unsigned) (cpus[c].mpstack) + MPSTACK; // tell it what to use for %esp
*(unsigned *)(APBOOTCODE-8) = (unsigned)&main; // tell it where to jump to
lapic_startap(cpus[c].apicid, (uint32_t) APBOOTCODE);
}
}
@@ -205,7 +207,7 @@ mp_startthem()
cprintf ("starting processor %d\n", c);
*(unsigned *)(APBOOTCODE-4) = (unsigned) (cpus[c].mpstack) + MPSTACK; // tell it what to use for %esp
- *(unsigned *)(APBOOTCODE-8) = (unsigned)&main; // tell it where to jump to
+ *(unsigned *)(APBOOTCODE-8) = (unsigned)mpmain; // tell it where to jump to
lapic_startap(cpus[c].apicid, (uint32_t) APBOOTCODE);
}